@@ -1,10 +1,7 @@
 /*
-  Copyright (c) 2007 Paolo Capriotti <p.capriotti@gmail.com>
-            
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
+    SPDX-FileCopyrightText: 2007 Paolo Capriotti <p.capriotti@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "animation.h"
 #include "knavalbattle_debug.h"
@@ -27,7 +24,7 @@ AnimationGroup::~AnimationGroup()
 void AnimationGroup::start(int t)
 {
     m_running = t;
-    for (Animation* a : qAsConst(m_animations)) {
+    for (Animation* a : std::as_const(m_animations)) {
         a->start(t);
     }
 }
