@@ -1,16 +1,13 @@
 /*
-  Copyright (c) 2007 Paolo Capriotti <p.capriotti@gmail.com>
-            
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
+    SPDX-FileCopyrightText: 2007 Paolo Capriotti <p.capriotti@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "animator.h"
 #include "animation.h"
 
-Animator* Animator::m_instance = 0;
+Animator* Animator::m_instance = nullptr;
 
 Animator::Animator()
 {
